@@ -1,6 +1,6 @@
 /*********************************************************************
  *
- *      Copyright (C) 1999-2004 Nathan Fiedler
+ *      Copyright (C) 1999-2005 Nathan Fiedler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: AboutAction.java 1126 2004-02-15 22:55:25Z nfiedler $
+ * $Id: AboutAction.java 1479 2005-02-05 08:11:06Z nfiedler $
  *
  ********************************************************************/
 
@@ -32,7 +32,10 @@ import java.awt.GridBagLayout;
 import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
+import java.util.Collections;
 import java.util.Enumeration;
+import java.util.Iterator;
+import java.util.List;
 import java.util.Properties;
 import javax.swing.ImageIcon;
 import javax.swing.JButton;
@@ -203,8 +206,11 @@ class AboutDialog extends JDialog {
         Properties props = System.getProperties();
         StringBuffer buf = new StringBuffer(1024);
         Enumeration names = props.propertyNames();
-        while (names.hasMoreElements()) {
-            String key = (String) names.nextElement();
+        List sortedNames = Collections.list(names);
+        Collections.sort(sortedNames);
+        Iterator iter = sortedNames.iterator();
+        while (iter.hasNext()) {
+            String key = (String) iter.next();
             buf.append(key);
             buf.append(" = ");
             buf.append(props.getProperty(key));
