@@ -1,6 +1,6 @@
 /*********************************************************************
  *
- *      Copyright (C) 2000-2002 Nathan Fiedler
+ *      Copyright (C) 2000-2004 Nathan Fiedler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,50 +16,46 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * PROJECT:     JSwat
- * MODULE:      JSwat Actions
- * FILE:        VMAttachAction.java
- *
- * AUTHOR:      Nathan Fiedler
- *
- * REVISION HISTORY:
- *      Name    Date            Description
- *      ----    ----            -----------
- *      nf      07/31/00        Initial version
- *      nf      08/10/00        Changed to use connectors
- *      nf      03/11/01        Store settings in Session
- *      nf      05/02/01        Fix bug 107, add a wait cursor
- *      nf      08/18/01        Fixed bug 152, handle dialog close
- *      nf      03/09/02        Fixed bug 409, deactivate session
- *      nf      04/04/02        Implemented #404, shmem transport
- *      nf      04/06/02        Making the layout look better
- *
- * DESCRIPTION:
- *      Defines the class responsible for making connections to
- *      remote debuggee VMs.
- *
- * $Id: VMAttachAction.java 629 2002-10-26 23:03:26Z nfiedler $
+ * $Id: VMAttachAction.java 1119 2004-02-10 19:21:58Z nfiedler $
  *
  ********************************************************************/
 
 package com.bluemarsh.jswat.action;
 
-import com.bluemarsh.jswat.*;
-import com.sun.jdi.*;
-import com.sun.jdi.connect.*;
-import com.sun.jdi.request.*;
-import java.awt.*;
-import java.awt.event.*;
-import java.io.*;
-import java.util.List;
-import java.util.Map;
-import javax.swing.*;
-import javax.swing.text.*;
-import javax.swing.border.EtchedBorder;
+import com.bluemarsh.jswat.NoAttachingConnectorException;
+import com.bluemarsh.jswat.Session;
+import com.bluemarsh.jswat.VMConnection;
+import com.bluemarsh.jswat.ui.EditPopup;
+import com.sun.jdi.connect.AttachingConnector;
+import java.awt.CardLayout;
+import java.awt.Container;
+import java.awt.Cursor;
+import java.awt.Font;
+import java.awt.Frame;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
+import javax.swing.AbstractButton;
+import javax.swing.BorderFactory;
+import javax.swing.ButtonGroup;
+import javax.swing.JButton;
+import javax.swing.JDialog;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JRadioButton;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.text.AttributeSet;
+import javax.swing.text.BadLocationException;
+import javax.swing.text.PlainDocument;
 
 /**
- * Class VMAttachAction allows the user to make a remote connection
- * to a debuggee VM.
+ * Class VMAttachAction allows the user to make a remote connection to a
+ * debuggee VM.
  *
  * @author  Nathan Fiedler
  */
@@ -87,28 +83,29 @@ public class VMAttachAction extends JSwatAction {
         dialog.pack();
         dialog.setLocationRelativeTo(win);
         dialog.setResizable(false);
-        dialog.show();
+        dialog.setVisible(true);
     } // actionPerformed
 
     /**
      * Dialog for getting remote attach parameters.
      */
-    protected class AttachDialog extends JDialog implements ActionListener, ItemListener {
+    protected class AttachDialog extends JDialog
+        implements ActionListener, ItemListener {
         /** Text field for host name. */
-        protected JTextField hostNameField;
+        private JTextField hostNameField;
         /** Text field for port number. */
-        protected JTextField portNumberField;
+        private JTextField portNumberField;
         /** Text field for share name. */
-        protected JTextField shareNameField;
+        private JTextField shareNameField;
         /** True if the shared name should be used instead of
          * the host name and port number. */
-        protected boolean useShared;
+        private boolean useShared;
         /** Card layout for shared memory and socket parameters. */
-        protected CardLayout cardLayout;
+        private CardLayout cardLayout;
         /** Panel in which card layout is used. */
-        protected JPanel bottomPanel;
+        private JPanel bottomPanel;
         /** Session through which we attach. */
-        protected Session session;
+        private Session session;
 
         /**
          * Constructs a AttachDialog with the given window and Session.
@@ -162,14 +159,19 @@ public class VMAttachAction extends JSwatAction {
             gbl.setConstraints(buttonPanel, gbc);
             allPanel.add(buttonPanel);
 
-            String useShmem = session.getProperty("useShmem");
-            useShared = Boolean.valueOf(useShmem).booleanValue();
+            String useShare = session.getProperty("useShare");
+            useShared = Boolean.valueOf(useShare).booleanValue();
 
             ButtonGroup bg = new ButtonGroup();
             JRadioButton rbutton = new JRadioButton(
                 Bundle.getString("Attach.shmemButton"), useShared);
             rbutton.setActionCommand("shared");
             rbutton.addItemListener(this);
+            AttachingConnector connector =
+                VMConnection.getAttachingConnector("dt_shmem");
+            if (connector == null) {
+                rbutton.setEnabled(false);
+            }
             bg.add(rbutton);
             buttonPanel.add(rbutton);
             rbutton = new JRadioButton(
@@ -199,12 +201,14 @@ public class VMAttachAction extends JSwatAction {
                 Bundle.getString("Attach.attachButton"));
             button.setActionCommand("attach");
             button.addActionListener(this);
+            button.setDefaultCapable(true);
             gbc.anchor = GridBagConstraints.CENTER;
             gbc.gridwidth = GridBagConstraints.RELATIVE;
             gbc.insets = new Insets(3, 10, 3, 10);
             gbc.weightx = 1.0;
             gbl.setConstraints(button, gbc);
             allPanel.add(button);
+            getRootPane().setDefaultButton(button);
 
             button = new JButton(
                 Bundle.getString("Attach.cancelButton"));
@@ -213,6 +217,8 @@ public class VMAttachAction extends JSwatAction {
             gbc.gridwidth = GridBagConstraints.REMAINDER;
             gbl.setConstraints(button, gbc);
             allPanel.add(button);
+
+            setDefaultCloseOperation(DISPOSE_ON_CLOSE);
         } // AttachDialog
 
         /**
@@ -245,7 +251,7 @@ public class VMAttachAction extends JSwatAction {
         protected boolean attachShmem() {
             if (session.isActive()) {
                 // Deactivate current session.
-                session.deactivate(false);
+                session.deactivate(false, this);
             }
 
             String shareName = shareNameField.getText();
@@ -256,12 +262,11 @@ public class VMAttachAction extends JSwatAction {
             }
 
             // Try to make the connection.
-            Log out = session.getStatusLog();
             VMConnection connection = null;
             try {
                 connection = VMConnection.buildConnection(shareName);
             } catch (NoAttachingConnectorException nace) {
-                displayError(win, swat.getResourceString(
+                displayError(win, com.bluemarsh.jswat.Bundle.getString(
                     "noShmemVMsFound"));
                 return false;
             }
@@ -270,7 +275,7 @@ public class VMAttachAction extends JSwatAction {
                 // Show a busy cursor while we attach to the debuggee.
                 win.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
                 try {
-                    connection.attachDebuggee(session);
+                    connection.attachDebuggee(session, true);
                 } finally {
                     win.setCursor(Cursor.getDefaultCursor());
                 }
@@ -278,7 +283,7 @@ public class VMAttachAction extends JSwatAction {
 
             // Save the values to the session settings for later reuse.
             session.setProperty("shareName", shareName);
-            session.setProperty("useShmem", "true");
+            session.setProperty("useShare", "true");
             return true;
         } // attachShmem
 
@@ -290,7 +295,7 @@ public class VMAttachAction extends JSwatAction {
         protected boolean attachSocket() {
             if (session.isActive()) {
                 // Deactivate current session.
-                session.deactivate(false);
+                session.deactivate(false, this);
             }
 
             String remoteHost = hostNameField.getText();
@@ -302,13 +307,12 @@ public class VMAttachAction extends JSwatAction {
             }
 
             // Try to make the connection.
-            Log out = session.getStatusLog();
             VMConnection connection = null;
             try {
                 connection = VMConnection.buildConnection(
                     remoteHost, remotePort);
             } catch (NoAttachingConnectorException nace) {
-                displayError(win, swat.getResourceString(
+                displayError(win, com.bluemarsh.jswat.Bundle.getString(
                     "noSocketVMsFound"));
                 return false;
             }
@@ -317,7 +321,7 @@ public class VMAttachAction extends JSwatAction {
                 // Show a busy cursor while we attach to the debuggee.
                 win.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
                 try {
-                    connection.attachDebuggee(session);
+                    connection.attachDebuggee(session, true);
                 } finally {
                     win.setCursor(Cursor.getDefaultCursor());
                 }
@@ -326,7 +330,7 @@ public class VMAttachAction extends JSwatAction {
             // Save the values to the session settings for later reuse.
             session.setProperty("remoteHost", remoteHost);
             session.setProperty("remotePort", remotePort);
-            session.setProperty("useShmem", "false");
+            session.setProperty("useShare", "false");
             return true;
         } // attachSocket
 
@@ -334,6 +338,7 @@ public class VMAttachAction extends JSwatAction {
          * Builds the shared memory parameters panel.
          *
          * @param  session  Session from which to get settings.
+         * @return  shared memory panel.
          */
         protected JPanel buildShmemPanel(Session session) {
             GridBagLayout gbl = new GridBagLayout();
@@ -358,10 +363,16 @@ public class VMAttachAction extends JSwatAction {
             gbl.setConstraints(example, gbc);
             allPanel.add(example);
 
-            example = new JLabel(Bundle.getString("Attach.shmemExample"));
-            example.setFont(new Font("Monospaced", Font.PLAIN, 12));
-            gbl.setConstraints(example, gbc);
-            allPanel.add(example);
+            JTextArea exampleArea = new JTextArea(
+                Bundle.getString("Attach.shmemExample"), 4, 50);
+            exampleArea.setEditable(false);
+            exampleArea.setLineWrap(true);
+            exampleArea.setFont(new Font("Monospaced", Font.PLAIN, 12));
+            exampleArea.setBorder(BorderFactory.createEtchedBorder());
+            EditPopup popup = new EditPopup(exampleArea, false, false);
+            exampleArea.addMouseListener(popup);
+            gbl.setConstraints(exampleArea, gbc);
+            allPanel.add(exampleArea);
 
             return allPanel;
         } // buildShmemPanel
@@ -370,6 +381,7 @@ public class VMAttachAction extends JSwatAction {
          * Builds the shared memory parameters panel.
          *
          * @param  session  Session from which to get settings.
+         * @return  socket panel.
          */
         protected JPanel buildSocketPanel(Session session) {
             GridBagLayout gbl = new GridBagLayout();
@@ -407,10 +419,16 @@ public class VMAttachAction extends JSwatAction {
             gbl.setConstraints(example, gbc);
             allPanel.add(example);
 
-            example = new JLabel(Bundle.getString("Attach.socketExample"));
-            example.setFont(new Font("Monospaced", Font.PLAIN, 12));
-            gbl.setConstraints(example, gbc);
-            allPanel.add(example);
+            JTextArea exampleArea = new JTextArea(
+                Bundle.getString("Attach.socketExample"), 4, 50);
+            exampleArea.setEditable(false);
+            exampleArea.setLineWrap(true);
+            exampleArea.setFont(new Font("Monospaced", Font.PLAIN, 12));
+            exampleArea.setBorder(BorderFactory.createEtchedBorder());
+            EditPopup popup = new EditPopup(exampleArea, false, false);
+            exampleArea.addMouseListener(popup);
+            gbl.setConstraints(exampleArea, gbc);
+            allPanel.add(exampleArea);
 
             return allPanel;
         } // buildSocketPanel
@@ -442,8 +460,10 @@ public class VMAttachAction extends JSwatAction {
          * @param  offs  offset in which to insert.
          * @param  str   string to insert.
          * @param  a     attribute set.
+         * @throws  BadLocationException
+         *          if the text offset is invalid.
          */
-        public void insertString(int offs, String str, AttributeSet a) 
+        public void insertString(int offs, String str, AttributeSet a)
             throws BadLocationException {
 
             if (str == null) {
