@@ -31,7 +31,7 @@
  *      nf      07/29/02        Fixed bug 602
  *      nf      11/22/03        Renamed
  *
- * $Id: AbstractBreakpoint.java 1146 2004-02-20 03:41:14Z nfiedler $
+ * $Id: AbstractBreakpoint.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -199,16 +199,6 @@ public abstract class AbstractBreakpoint
         return shouldResume;
     } // eventOccurred
 
-    /**
-     * Returns the event request for this breakpoint, if the
-     * breakpoint has been resolved.
-     *
-     * @return  breakpoint's event request, or null if unresolved.
-     */
-    public EventRequest eventRequest() {
-        return null;
-    } // eventRequest
-
     /**
      * Notify breakpoint listeners that this breakpoint has changed.
      */
