@@ -28,7 +28,7 @@
  *      nf      03/24/01        Initial version
  *      nf      08/16/01        Removed the colors
  *
- * $Id: Breakpoint.java 1048 2003-11-16 07:27:16Z nfiedler $
+ * $Id: Breakpoint.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -93,14 +93,6 @@ public interface Breakpoint {
      */
     void destroy();
 
-    /**
-     * Returns the event request for this breakpoint, if the
-     * breakpoint has been resolved.
-     *
-     * @return  breakpoint's event request, or null if unresolved.
-     */
-    EventRequest eventRequest();
-
     /**
      * Gets the breakpoint group to which this breakpoint belongs.
      *
