@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: BreakpointManager.java 1311 2004-09-29 05:18:12Z nfiedler $
+ * $Id: BreakpointManager.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -448,14 +448,12 @@ public class BreakpointManager implements Manager, VMEventListener {
         EventRequest eventRequest = e.request();
         Object o = eventRequest.getProperty("breakpoint");
         if (o != null && o instanceof ResolvableBreakpoint) {
-            ResolvableBreakpoint bp = (ResolvableBreakpoint) o;
-
             // Yes, a breakpoint is waiting to resolve.
-            EventRequest oldER = bp.eventRequest();
-            EventRequest newER = null;
+            ResolvableBreakpoint bp = (ResolvableBreakpoint) o;
+            boolean resolved = false;
             try {
                 if (bp.isEnabled()) {
-                    newER = bp.resolveAgainstEvent((ClassPrepareEvent) e);
+                    resolved = bp.resolveAgainstEvent((ClassPrepareEvent) e);
                 }
             } catch (ResolveException re) {
                 StringBuffer sb = new StringBuffer(80);
@@ -471,11 +469,10 @@ public class BreakpointManager implements Manager, VMEventListener {
                 owningSession.handleDebugEvent(e);
                 return false;
             }
-            if (newER != null && oldER != newER) {
+            if (resolved) {
                 if (logger.isLoggable(Level.INFO)) {
                     logger.info("resolved " + bp);
                 }
-                // Hurray, it has just been (re)resolved.
                 fireChange(bp, BreakpointEvent.TYPE_MODIFIED);
             }
         }
