@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: LineBreakpoint.java 1245 2004-04-30 02:33:53Z nfiedler $
+ * $Id: LineBreakpoint.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -28,8 +28,11 @@ import com.bluemarsh.jswat.util.Names;
 import com.sun.jdi.AbsentInformationException;
 import com.sun.jdi.ClassType;
 import com.sun.jdi.Location;
+import com.sun.jdi.ReferenceType;
 import com.sun.jdi.request.EventRequest;
+import java.util.Iterator;
 import java.util.List;
+import java.util.prefs.Preferences;
 
 /**
  * Class LineBreakpoint extends the LocationBreakpoint class. Its
@@ -39,6 +42,8 @@ import java.util.List;
  * @author Nathan Fiedler
  */
 public class LineBreakpoint extends LocationBreakpoint {
+    /** Name of the source file, if provided. */
+    private String sourceName;
 
     /**
      * Default constructor for deserialization.
@@ -63,6 +68,34 @@ public class LineBreakpoint extends LocationBreakpoint {
         lineNumber = line;
     } // LineBreakpoint
 
+    /**
+     * Constructs a LineBreakpoint for the given class at the specified
+     * line within that class, defined in the named source file.
+     *
+     * @param  classPattern  name of class in which to set breakpoint,
+     *                       possibly using wildcards.
+     * @param  source        name of the source file.
+     * @param  line          line at which to stop.
+     * @throws  ClassNotFoundException
+     *          if classPattern is not a valid identifier.
+     */
+    public LineBreakpoint(String classPattern, String source, int line)
+        throws ClassNotFoundException {
+
+        this(classPattern, line);
+        sourceName = source;
+    } // LineBreakpoint
+
+    /**
+     * Returns the name of the source file for the class this breakpoint
+     * is set within. May not be known, in which case null is returned.
+     *
+     * @return  source name, or null if unknown.
+     */
+    public String getSourceName() {
+        return sourceName;
+    } // getSourceName
+
     /**
      * Returns the user interface widget for customizing this breakpoint.
      * This method returns a new ui adapter each time it is called.
@@ -73,6 +106,18 @@ public class LineBreakpoint extends LocationBreakpoint {
         return new LineBreakpointUI(this);
     } // getUIAdapter
 
+    /**
+     * Reads the breakpoint properties from the given preferences node.
+     *
+     * @param  prefs  Preferences node from which to initialize this
+     *                breakpoint.
+     * @return  true if successful, false otherwise.
+     */
+    public boolean readObject(Preferences prefs) {
+        sourceName = prefs.get("sourceName", null);
+        return super.readObject(prefs);
+    } // readObject
+
     /**
      * Determine the location at which to set the breakpoint using
      * the given class type.
@@ -87,12 +132,20 @@ public class LineBreakpoint extends LocationBreakpoint {
         List locs = null;
         try {
             locs = clazz.locationsOfLine(lineNumber);
+            if (locs.isEmpty()) {
+                List inners = clazz.nestedTypes();
+                Iterator iter = inners.iterator();
+                while (iter.hasNext() && locs.isEmpty()) {
+                    ReferenceType type = (ReferenceType) iter.next();
+                    locs = type.locationsOfLine(lineNumber);
+                }
+                if (locs.isEmpty()) {
+                    throw new ResolveException(new LineNotFoundException());
+                }
+            }
         } catch (AbsentInformationException aie) {
             throw new ResolveException(aie);
         }
-        if (locs.size() == 0) {
-            throw new ResolveException(new LineNotFoundException());
-        }
         // We assume the first location for this line is good enough.
         return (Location) locs.get(0);
     } // resolveLocation
@@ -141,4 +194,22 @@ public class LineBreakpoint extends LocationBreakpoint {
         }
         return buf.toString();
     } // toString
+
+    /**
+     * Writes the breakpoint properties to the given preferences node.
+     * It is assumed that the preferences node is completely empty.
+     *
+     * @param  prefs  Preferences node to which to serialize this
+     *                breakpoint.
+     * @return  true if successful, false otherwise.
+     */
+    public boolean writeObject(Preferences prefs) {
+        if (!super.writeObject(prefs)) {
+            return false;
+        }
+        if (sourceName != null) {
+            prefs.put("sourceName", sourceName);
+        }
+        return true;
+    } // writeObject
 } // LineBreakpoint
