@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: LocationBreakpoint.java 1150 2004-02-25 00:47:11Z nfiedler $
+ * $Id: LocationBreakpoint.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -277,7 +277,7 @@ public abstract class LocationBreakpoint extends ResolvableBreakpoint
         // Delete and recreate the event request using the current
         // breakpoint settings.
         deleteEventRequest();
-        deletePrepareRequest();
+        deletePrepareRequests();
         if (enabled) {
             // Do a complete re-resolve so we account for hotswapped
             // classes, which need to be found again.
