@@ -29,7 +29,7 @@
  *      nf      09/18/02        Fixed bug 615
  *      nf      12/01/02        Fixed bug 680
  *
- * $Id: UncaughtExceptionBreakpoint.java 1064 2003-11-22 23:55:57Z nfiedler $
+ * $Id: UncaughtExceptionBreakpoint.java 1461 2005-01-31 07:59:48Z nfiedler $
  *
  ********************************************************************/
 
@@ -197,16 +197,6 @@ public class UncaughtExceptionBreakpoint extends AbstractBreakpoint
         return shouldResume;
     } // eventOccurred
 
-    /**
-     * Returns the event request for this breakpoint, if the
-     * breakpoint has been resolved.
-     *
-     * @return  breakpoint's event request, or null if unresolved.
-     */
-    public EventRequest eventRequest() {
-        return eventRequest;
-    } // eventRequest
-
     /**
      * Returns the stop-on-caught status.
      *
