@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: BreakPanel.java 1157 2004-02-25 09:28:54Z nfiedler $
+ * $Id: BreakPanel.java 1313 2004-09-29 05:20:24Z nfiedler $
  *
  ********************************************************************/
 
@@ -56,6 +56,7 @@ import java.io.File;
 import java.io.IOException;
 import java.text.MessageFormat;
 import java.util.ConcurrentModificationException;
+import java.util.Enumeration;
 import java.util.Iterator;
 import javax.swing.JButton;
 import javax.swing.JComponent;
@@ -63,6 +64,8 @@ import javax.swing.JPanel;
 import javax.swing.JScrollPane;
 import javax.swing.JTree;
 import javax.swing.UIManager;
+import javax.swing.event.TreeExpansionEvent;
+import javax.swing.event.TreeExpansionListener;
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.DefaultTreeCellRenderer;
 import javax.swing.tree.DefaultTreeModel;
@@ -86,6 +89,8 @@ public class BreakPanel extends AbstractPanel
     private JTree uiTree;
     /** Containing component object. */
     private JComponent uiComponent;
+    /** Our tree expansion listener for setting the groups as expanded. */
+    private TreeExpansionListener treeExpansionListener;
 
     /**
      * Constructs a BreakPanel.
@@ -561,6 +566,10 @@ public class BreakPanel extends AbstractPanel
      * @param  session  debugging Session object.
      */
     public void refresh(Session session) {
+        if (treeExpansionListener != null) {
+            uiTree.removeTreeExpansionListener(treeExpansionListener);
+        }
+
         BreakpointManager brkman = (BreakpointManager)
             session.getManager(BreakpointManager.class);
 
@@ -582,13 +591,55 @@ public class BreakPanel extends AbstractPanel
         // Set the model now that it has been built out.
         uiTree.setModel(model);
 
-        // Expand all of the rows in the tree.
-        int row = 0;
-        while (row < uiTree.getRowCount()) {
-            uiTree.expandRow(row++);
+        // Set expansion state for all of the rows in the tree.
+        Enumeration nodes = ((DefaultMutableTreeNode)
+                model.getRoot()).depthFirstEnumeration();
+        while (nodes.hasMoreElements()) {
+            DefaultMutableTreeNode node = (DefaultMutableTreeNode)
+                nodes.nextElement();
+            Object o = node.getUserObject();
+            if (o instanceof BreakpointGroup) {
+                TreePath path = new TreePath(model.getPathToRoot(node));
+                BreakpointGroup grp = (BreakpointGroup) o;
+                if (grp.isExpanded()) {
+                    uiTree.expandPath(path);
+                } else {
+                    uiTree.collapsePath(path);
+                }
+            }
         }
+
+        if (treeExpansionListener == null) {
+            treeExpansionListener = new TreeExpansionListener() {
+                public void treeExpanded(TreeExpansionEvent event) {
+                    handlePathExpanded(event.getPath(), true);
+                }
+
+                public void treeCollapsed(TreeExpansionEvent event) {
+                    handlePathExpanded(event.getPath(), false);
+                }
+            };
+        }
+        uiTree.addTreeExpansionListener(treeExpansionListener);
     } // refresh
 
+    /**
+     * Do something about the tree expansion.
+     *
+     * @param  path      path to expanded node.
+     * @param  expanded  true if the node is expanded.
+     */
+    private void handlePathExpanded(TreePath path, boolean expanded) {
+        DefaultMutableTreeNode node = (DefaultMutableTreeNode)
+            path.getLastPathComponent();
+        Object o = node.getUserObject();
+        // It has to be BreakpointGroup, otherwise it should be an error.
+        if (o instanceof BreakpointGroup) {
+            BreakpointGroup grp = (BreakpointGroup) o;
+            grp.setExpanded(expanded);
+        }
+    } // handlePathExpanded
+
     /**
      * Show the source code for the first selected breakpoint,
      * if the breakpoint is indeed locatable.
